@@ -199,15 +199,21 @@ class BaseParser:
     def load_conllu(*args, **kwargs):
         """Wrapper for ``Conllu.load()``"""
         silent = kwargs.pop('silent', None)
-        return Conllu.load(*args, **kwargs,
-                           log_file=None if silent else LOG_FILE)
+        if silent:
+            kwargs['log_file'] = None
+        elif 'log_file' not in kwargs:
+            kwargs['log_file'] = LOG_FILE
+        return Conllu.load(*args, **kwargs)
 
     @staticmethod
     def save_conllu(*args, **kwargs):
         """Wrapper for ``Conllu.save()``"""
         silent = kwargs.pop('silent', None)
-        return Conllu.save(*args, **kwargs,
-                           log_file=None if silent else LOG_FILE)
+        if silent:
+            kwargs['log_file'] = None
+        elif 'log_file' not in kwargs:
+            kwargs['log_file'] = LOG_FILE
+        return Conllu.save(*args, **kwargs)
 
     @staticmethod
     def split_corpus(corpus, split=[.8, .1, .1], save_split_to=None,
@@ -218,7 +224,7 @@ class BaseParser:
                        sentences in Parsed CoNLL-U
         :param split: list of sizes of the necessary *corpus* parts. If values
                       are of int type, they are interpreted as lengths of new
-                      corpuses in sentences; if values are float, they are
+                      corpora in sentences; if values are float, they are
                       proportions of a given *corpus*. The types of the
                       *split* values can't be mixed: they are either all int,
                       or all float. The sum of float values must be less or
@@ -229,7 +235,7 @@ class BaseParser:
                               don't save parts to files) or its length must be
                               equal to the length of *split*
         :param silent: if True, suppress output
-        :return: a list of new corpuses
+        :return: a list of new corpora
         """
         assert save_split_to is None or len(save_split_to) == len(split), \
                'ERROR: lengths of split and save_split_to must be equal'
@@ -265,7 +271,7 @@ class BaseParser:
         if isinstance(corpus, str):
             corpus = cls.load_conllu(corpus, silent=silent)
         return (s[0] if not asis and isinstance(s, tuple) else s
-                   for s in corpus)
+                    for s in corpus)
 
     def _predict_sents(self, sentences, predict_method, save_to=None):
         silent_save = False
@@ -743,16 +749,16 @@ def _evaluate(test_corpus, gold_corpus, what=None, feat=None, silent=False):
     if what:
         what = what.lower()
     assert what in [None, 'lemma', 'upos', 'feats']
-    gold_corpus = list(MorphParser._get_corpus(gold_corpus))
-    test_corpus = list(MorphParser._get_corpus(test_corpus))
+    gold_corpus = list(BaseParser._get_corpus(gold_corpus))
+    test_corpus = list(BaseParser._get_corpus(test_corpus))
     feat_vals = {}
     for corpus in [gold_corpus, test_corpus]:
         for sent in corpus:
             if isinstance(sent, tuple):
                 sent = sent[0]
             for token in sent:
-                for feat, feat_val in token['FEATS'].items():
-                    feat_vals.setdefault(feat, set()).add(feat_val)
+                for feat_, feat_val in token['FEATS'].items():
+                    feat_vals.setdefault(feat_, set()).add(feat_val)
     if not silent:
         print('Evaluate', file=LOG_FILE)
     n = c = nt = ct = 0
