@@ -773,8 +773,7 @@ class MorphParserNE(BaseParser):
                             cc += 1
                         elif not gold_ne or (ne and gold_ne != ne):
                             w1 += 1
-                        elif not test_ne \
-                          or (ne and test_ne != ne):
+                        elif not test_ne or (ne and test_ne != ne):
                             w2 += 1
                         else:
                             w += 1
@@ -791,9 +790,9 @@ class MorphParserNE(BaseParser):
                 print(header + ' total: {}'.format(n), file=LOG_FILE)
                 print(sp   + ' correct: {}'.format(c), file=LOG_FILE)
                 print(sp   + '   wrong: {} [{} excess / {} absent{}]'
-                                  .format(n - c, w1, w2, '' if ne else
-                                                         ' / {} wrong type'
-                                                             .format(w)),
+                                 .format(n - c, w1, w2, '' if ne else
+                                                        ' / {} wrong type'
+                                                            .format(w)),
                       file=LOG_FILE)
                 print(sp   + 'Accuracy: {}'.format(c / n if n > 0 else 1.))
                 print('[Total accuracy: {}]'.format(cc / nn if nn > 0 else 1.))
